"""认证和安全模块."""

import time
from collections import defaultdict
from typing import Dict, List

from fastapi import HTTPException, Request, status

from .config import get_config


class RateLimiter:
    """简单的速率限制器."""
    
    def __init__(self):
        self.requests: Dict[str, List[float]] = defaultdict(list)
    
    def is_allowed(self, client_ip: str, limit: int, window: int = 60) -> bool:
        """检查是否允许请求."""
        now = time.time()
        # 清理过期的请求记录
        self.requests[client_ip] = [
            req_time for req_time in self.requests[client_ip]
            if now - req_time < window
        ]
        
        # 检查是否超过限制
        if len(self.requests[client_ip]) >= limit:
            return False
        
        # 记录当前请求
        self.requests[client_ip].append(now)
        return True


# 全局速率限制器实例
rate_limiter = RateLimiter()


def verify_api_key(api_key: str) -> bool:
    """验证 API 密钥."""
    config = get_config()
    return api_key == config.server.api_key


def check_ip_allowed(client_ip: str) -> bool:
    """检查 IP 是否被允许."""
    config = get_config()
    allowed_ips = config.security.allowed_ips
    
    # 如果没有配置允许的 IP，则允许所有
    if not allowed_ips:
        return True
    
    return client_ip in allowed_ips


def check_rate_limit(client_ip: str) -> bool:
    """检查速率限制."""
    config = get_config()
    return rate_limiter.is_allowed(client_ip, config.security.rate_limit)


def authenticate_request(request: Request, api_key: str) -> None:
    """验证请求."""
    client_ip = request.client.host if request.client else "unknown"
    
    # 检查 IP 白名单
    if not check_ip_allowed(client_ip):
        raise HTTPException(
            status_code=status.HTTP_403_FORBIDDEN,
            detail="IP 地址不在允许列表中"
        )
    
    # 检查速率限制
    if not check_rate_limit(client_ip):
        raise HTTPException(
            status_code=status.HTTP_429_TOO_MANY_REQUESTS,
            detail="请求过于频繁，请稍后再试"
        )
    
    # 验证 API 密钥
    if not verify_api_key(api_key):
        raise HTTPException(
            status_code=status.HTTP_401_UNAUTHORIZED,
            detail="无效的 API 密钥"
        )
