"""主应用模块."""

import logging
import time
from datetime import datetime
from pathlib import Path

import uvicorn
from fastapi import FastAPI, HTTPException, Request, status
from fastapi.middleware.cors import CORSMiddleware
from fastapi.responses import JSONResponse

from . import __version__
from .auth import authenticate_request
from .config import get_config
from .models import NotificationRequest, NotificationResponse, SimpleNotificationRequest, SMSMessage, SystemStatus
from .notifier import notification_manager

# 配置日志
def setup_logging():
    """设置日志配置."""
    try:
        config = get_config()
        log_level = getattr(logging, config.logging.level.upper(), logging.INFO)
        
        # 创建日志目录
        if config.logging.file:
            log_file = Path(config.logging.file)
            log_file.parent.mkdir(parents=True, exist_ok=True)
        
        # 配置日志格式
        logging.basicConfig(
            level=log_level,
            format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
            handlers=[
                logging.StreamHandler(),
                logging.FileHandler(config.logging.file) if config.logging.file else logging.NullHandler()
            ]
        )
    except Exception as e:
        # 如果配置加载失败，使用默认日志配置
        logging.basicConfig(level=logging.INFO)
        logging.error(f"日志配置失败，使用默认配置: {e}")

setup_logging()
logger = logging.getLogger(__name__)

# 应用启动时间
start_time = time.time()

# 创建 FastAPI 应用
app = FastAPI(
    title="SMS Forwarder",
    description="iOS SMS to Android notification forwarder",
    version=__version__,
    docs_url="/docs",
    redoc_url="/redoc"
)

# 添加 CORS 中间件
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)


@app.exception_handler(Exception)
async def global_exception_handler(request: Request, exc: Exception):
    """全局异常处理器."""
    logger.error(f"未处理的异常: {exc}", exc_info=True)
    return JSONResponse(
        status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
        content={"detail": "服务器内部错误"}
    )


@app.get("/")
async def root():
    """根路径."""
    return {
        "message": "SMS Forwarder API",
        "version": __version__,
        "docs": "/docs"
    }


@app.get("/health")
async def health_check():
    """健康检查."""
    return {"status": "healthy", "timestamp": datetime.now()}


@app.get("/status", response_model=SystemStatus)
async def get_status():
    """获取系统状态."""
    stats = notification_manager.get_stats()
    return SystemStatus(
        version=__version__,
        uptime=time.time() - start_time,
        notifications_sent=stats["sent"],
        notifications_failed=stats["failed"]
    )


@app.post("/notify", response_model=NotificationResponse)
async def send_notification(request: Request, notification_request: NotificationRequest):
    """发送通知（完整版）."""
    try:
        # 验证请求
        authenticate_request(request, notification_request.api_key)

        # 发送通知
        success = notification_manager.send_sms_notification(notification_request.message)

        if success:
            logger.info(f"通知发送成功: {notification_request.message.sender}")
            return NotificationResponse(
                success=True,
                message="通知发送成功"
            )
        else:
            logger.error(f"通知发送失败: {notification_request.message.sender}")
            return NotificationResponse(
                success=False,
                message="通知发送失败"
            )

    except HTTPException:
        raise
    except Exception as e:
        logger.error(f"处理通知请求时出错: {e}", exc_info=True)
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail="处理请求时出错"
        )


@app.post("/notify/simple", response_model=NotificationResponse)
async def send_simple_notification(request: Request, simple_request: SimpleNotificationRequest):
    """发送通知（简化版）- 只需要内容，时间戳自动生成."""
    try:
        # 验证请求
        authenticate_request(request, simple_request.api_key)

        # 创建 SMS 消息对象，时间戳自动生成
        sms_message = SMSMessage(
            content=simple_request.content,
            sender=simple_request.sender or "iPhone"
        )

        # 发送通知
        success = notification_manager.send_sms_notification(sms_message)

        if success:
            logger.info(f"简化通知发送成功: {sms_message.sender}")
            return NotificationResponse(
                success=True,
                message="通知发送成功"
            )
        else:
            logger.error(f"简化通知发送失败: {sms_message.sender}")
            return NotificationResponse(
                success=False,
                message="通知发送失败"
            )

    except HTTPException:
        raise
    except Exception as e:
        logger.error(f"处理简化通知请求时出错: {e}", exc_info=True)
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail="处理请求时出错"
        )


@app.post("/reload")
async def reload_config(request: Request, api_key: str):
    """重新加载配置."""
    try:
        # 验证 API 密钥
        authenticate_request(request, api_key)
        
        # 重新加载通知服务
        notification_manager.reload_services()
        
        return {"message": "配置重新加载成功"}
        
    except HTTPException:
        raise
    except Exception as e:
        logger.error(f"重新加载配置时出错: {e}", exc_info=True)
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail="重新加载配置失败"
        )


def main():
    """主函数."""
    try:
        config = get_config()
        logger.info(f"启动 SMS Forwarder v{__version__}")
        logger.info(f"服务器配置: {config.server.host}:{config.server.port}")
        
        # 启动服务器
        uvicorn.run(
            "sms_forwarder.main:app",
            host=config.server.host,
            port=config.server.port,
            log_level=config.logging.level.lower(),
            access_log=True
        )
    except Exception as e:
        logger.error(f"启动服务器失败: {e}", exc_info=True)
        raise


if __name__ == "__main__":
    main()
