"""通知发送模块."""

import logging
from datetime import datetime
from typing import Dict, List

import apprise

from .config import get_config
from .models import SMSMessage

logger = logging.getLogger(__name__)


class NotificationManager:
    """通知管理器."""
    
    def __init__(self):
        self.apprise_obj = apprise.Apprise()
        self.stats = {
            "sent": 0,
            "failed": 0
        }
        self._load_services()
    
    def _load_services(self) -> None:
        """加载通知服务."""
        config = get_config()
        
        # 清空现有服务
        self.apprise_obj.clear()
        
        # 添加启用的服务
        for service in config.notifications.services:
            if service.enabled:
                try:
                    self.apprise_obj.add(service.url)
                    logger.info(f"已加载通知服务: {service.name}")
                except Exception as e:
                    logger.error(f"加载通知服务失败 {service.name}: {e}")
        
        if len(self.apprise_obj) == 0:
            logger.warning("没有可用的通知服务")
    
    def reload_services(self) -> None:
        """重新加载通知服务."""
        logger.info("重新加载通知服务...")
        self._load_services()
    
    def send_sms_notification(self, sms: SMSMessage) -> bool:
        """发送短信通知."""
        config = get_config()
        template = config.notifications.templates.sms
        
        # 格式化通知内容
        title = template.title.format(
            sender=sms.sender,
            timestamp=sms.timestamp.strftime("%Y-%m-%d %H:%M:%S") if sms.timestamp else "未知"
        )
        
        body = template.body.format(
            sender=sms.sender,
            content=sms.content,
            timestamp=sms.timestamp.strftime("%Y-%m-%d %H:%M:%S") if sms.timestamp else "未知"
        )
        
        return self._send_notification(title, body)
    
    def send_system_notification(self, message: str) -> bool:
        """发送系统通知."""
        config = get_config()
        template = config.notifications.templates.system
        
        title = template.title
        body = template.body.format(message=message)
        
        return self._send_notification(title, body)
    
    def _send_notification(self, title: str, body: str) -> bool:
        """发送通知."""
        try:
            if len(self.apprise_obj) == 0:
                logger.error("没有可用的通知服务")
                self.stats["failed"] += 1
                return False
            
            # 发送通知
            result = self.apprise_obj.notify(
                title=title,
                body=body
            )
            
            if result:
                logger.info(f"通知发送成功: {title}")
                self.stats["sent"] += 1
                return True
            else:
                logger.error(f"通知发送失败: {title}")
                self.stats["failed"] += 1
                return False
                
        except Exception as e:
            logger.error(f"发送通知时出错: {e}")
            self.stats["failed"] += 1
            return False
    
    def get_stats(self) -> Dict[str, int]:
        """获取统计信息."""
        return self.stats.copy()
    
    def get_services_info(self) -> List[Dict[str, str]]:
        """获取服务信息."""
        config = get_config()
        services_info = []
        
        for service in config.notifications.services:
            services_info.append({
                "name": service.name,
                "enabled": service.enabled,
                "url_scheme": service.url.split("://")[0] if "://" in service.url else "unknown"
            })
        
        return services_info


# 全局通知管理器实例
notification_manager = NotificationManager()
